
#ifndef _C14_kl684_
#define _C14_kl684_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F165_1493(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit684(void);

#ifdef __cplusplus
}
#endif

#endif
